device_slice

Function device_slice 

pub unsafe fn device_slice<'a, T>(addr: usize, n: usize) -> &'a [T]
View n elements of type T at device address addr as a shared slice.

Safety

addr must point to n valid, aligned, initialised T that outlive the returned borrow and are not mutated through another path meanwhile.