pub fn fence()Expand description
Full hardware memory fence (fence rw, rw) that also bars compiler
reordering. This is an ordering barrier, not an atomic operation.
pub fn fence()Full hardware memory fence (fence rw, rw) that also bars compiler
reordering. This is an ordering barrier, not an atomic operation.