set_tensor_mask

Function set_tensor_mask 

pub fn set_tensor_mask(mask: u16)
Write the per-row enable mask for the next TensorFMA.

Bit i in mask enables row i of the A tile. Setting bit i = 0 suppresses the update to C row i (useful for partial M tiles when the mask register is more convenient than setting AROWS). For most uses, leave the mask at its reset value of all-ones and control the tile size via the AROWS field in tensor_fma32.