pub fn trace_str(text: &[u8])
Write text as a NUL-terminated string trace entry for the current hart, exactly as the SDK’s Trace_String does (reserve via the control block, then write a trace_string_t).
text
Trace_String
trace_string_t