pub unsafe fn tensor_fma32(xs: u64)Expand description
Initiate an asynchronous TensorFMA32.
Issues csrrw x0, 0x801, xs where xs is built by fma32_xs. The
operation is asynchronous: call tensor_wait(TensorEvent::Fma) before
reading the FP register file or issuing a subsequent tensor_store.
Safety
- The L1 scratchpad must be fully populated (TensorLoad with subsequent
tensor_wait(Load0)) before this call whentenb = false, or equivalentlytensor_load_bmust have been issued before this call for the TenB path. - Must be called from the primary hart of the Minion.